ID {{ formGroup.controls["id"].value }}

Recompile all shapes in this CoordSet

Key {{ formGroup.controls["key"].value }} Name Comment Order Enabled Light Mode Enabled View Settings

#### Initial Position

Initial Pan X Initial Pan Y Initial Zoom Position On Zoom
Initial Dark Mode

#### Background Colors

Dark Background Light Background

#### Zoom Limits

Minimum Zoom Maximum Zoom
Grid Sizes

#### Z-Grids

Z-Grids in the Peek diagram provide performance when viewing a large diagram and when zoomed into to the detail of a diagram.

When zoomed out, grids are larger, and contain less detail, making them quick to load and render.

When zoomed in, the grid X,Y size is smaller, and it contain all the detail.

Order

This field is the order of the z-grids.

Please ensure the zoom level min/max ranges are consecutive across all z-grids.

Min Max X Grid Y Grid Smallest Text

The smallest text that will be compiled into the grids at the maximum zoom level.

Smallest Shape

The smallest shape that will be compiled into the grids at the maximum zoom level.

This value is used to filter out shapes smaller than the value, and the shapes largest appearance within the grid. Which is at the maxZoom value.

Zoomed out zGrids can have larger values to remove detail, the most detailed grids can have a smaller value, Most likely no smaller than 2 as users will not get any benefit from a 2 pixel shape.

Min Grids

The number of grids that will appear on the screen at the minimum zoom level on a 2560x1440 (2k) screen.

Max Grids

The number of grids that will appear on the screen at the maximum zoom level on a 2560x1440 (2k) screen.

{{ getMinGridsDisplay(grid) }} {{ getMaxGridsDisplay(grid) }}

Remove this grid size

Feature Toggles Display Group Templates Enabled Edge Templates Enabled Branches Enabled Edit Settings Edit Enabled
Default Layer Default Level Default Color Default Line Style Default Text Style

#### Vertex Settings

Default Vertex Coord Set Default Vertex Group Name

#### Edge Settings

Default Edge Coord Set Default Edge Group Name
Access Control User Groups Allowed User Groups Denied Additional Data Data (JSON)